pub trait Metadata:
DeserializeOwned
+ Serialize
+ Clone
+ Send {
type Error: Clone + MetadataError;
// Required methods
fn timestamp(&self) -> Timestamp;
fn set_timestamp(&mut self, timestamp: Timestamp);
fn errors(&self) -> Option<&[Self::Error]>;
fn set_errors(&mut self, errors: Vec<Self::Error>);
// Provided methods
fn has_errors(&self) -> bool { ... }
fn merge(&mut self, other: Self) { ... }
}Required Associated Types
Sourcetype Error: Clone + MetadataError
type Error: Clone + MetadataError
The type of error returned in this metadata.
Required Methods
Sourcefn set_timestamp(&mut self, timestamp: Timestamp)
fn set_timestamp(&mut self, timestamp: Timestamp)
Overrides the timestamp at which this value was recorded.
Sourcefn errors(&self) -> Option<&[Self::Error]>
fn errors(&self) -> Option<&[Self::Error]>
Returns the errors recorded with this value, if any.
Sourcefn set_errors(&mut self, errors: Vec<Self::Error>)
fn set_errors(&mut self, errors: Vec<Self::Error>)
Overrides the errors associated with this value.
Provided Methods
Sourcefn has_errors(&self) -> bool
fn has_errors(&self) -> bool
Returns whether any errors are recorded on this value.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".